@@ -8,7 +8,7 @@ use IO::Gunzip;
 require Exporter ;
 use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS $RawInflateError);
 
-$VERSION = '2.000_01';
+$VERSION = '2.000_02';
 $RawInflateError = '';
 
 @ISA    = qw(Exporter IO::BaseInflate);
@@ -315,6 +315,12 @@ This parameter defaults to 0.
 
 
 
+=item -Append =E<gt> 0|1
+
+TODO
+
+
+
 =back
 
 
@@ -379,9 +385,20 @@ and if you want to compress each file one at a time, this will do the trick
 The format of the constructor for IO::RawInflate is shown below
 
 
-    my $z = new IO::RawInflate $input [OPTS];
+    my $z = new IO::RawInflate $input [OPTS]
+        or die "IO::RawInflate failed: $RawInflateError\n";
 
-Returns an IO::RawInflate object on success and undef on failure.
+Returns an C<IO::RawInflate> object on success and undef on failure.
+The variable C<$RawInflateError> will contain an error message on failure.
+
+If you are running Perl 5.005 or better the object, C<$z>, returned from 
+IO::RawInflate can be used exactly like an L<IO::File|IO::File> filehandle. 
+This means that all normal input file operations can be carried out with C<$z>. 
+For example, to read a line from a compressed file/buffer you can use either 
+of these forms
+
+    $line = $z->getline();
+    $line = <$z>;
 
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
@@ -463,14 +480,30 @@ of C<$num> bytes.
 
 This option defaults to 4096.
 
+=item -InputLength =E<gt> $size
+
+When present this option will limit the number of compressed bytes read from
+the input file/buffer to C<$size>. This option can be used in the situation
+where there is useful data directly after the compressed data stream and you
+know beforehand the exact length of the compressed data stream. 
+
+This option is mostly used when reading from a filehandle, in which case the
+file pointer will be left pointing to the first byte directly after the
+compressed data stream.
+
+
+
+This option defaults to off.
+
 =item -Append =E<gt> 0|1
 
 This option controls what the C<read> method does with uncompressed data.
 
-If set to 1, all uncompressed data will be appended to the output parameter.
+If set to 1, all uncompressed data will be appended to the output parameter of
+the C<read> method.
 
-If set to 0, the contents of the output parameter will be overwritten by the
-uncompressed data.
+If set to 0, the contents of the output parameter of the C<read> method will be
+overwritten by the uncompressed data.
 
 Defaults to 0.
 
@@ -702,6 +735,8 @@ Same as doing this
 
 L<Compress::Zlib>, L<IO::Gzip>, L<IO::Gunzip>, L<IO::Deflate>, L<IO::Inflate>, L<IO::RawDeflate>, L<IO::AnyInflate>
 
+L<Compress::Zlib::FAQ|Compress::Zlib::FAQ>
+
 L<File::GlobMapper|File::GlobMapper>, L<Archive::Tar|Archive::Zip>,
 L<IO::Zlib|IO::Zlib>
 
